from botocore.auth import SigV4Auth
from botocore.awsrequest import AWSRequest
import requests

class AWSV4Sign(requests.auth.AuthBase):
    """
    AWS V4 Request Signer for Requests.
    """

    def __init__(self, credentials, region, service):
        if not region:
            raise ValueError("You must supply an AWS region")
        self.credentials = credentials
        self.region = region
        self.service = service

    def __call__(self, r):
        request = AWSRequest(method=r.method.upper(), url=r.url, data=r.body)
        SigV4Auth(self.credentials, self.service, self.region).add_auth(request)
        r.headers.update(dict(request.headers.items()))
        return r


#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='requests_aws_sign',
    version='0.1.0',
    packages=[ 'requests_aws_sign' ],
    install_requires=[ 'requests>=2.0.0', 'boto3' ],
    provides=[ 'requests_aws_sign' ],
    author='Justin Menga',
    author_email='justin.menga@gmail.com',
    url='https://github.com/jmenga/requests-aws-sign',
    description='This package provides AWS V4 request signing using the requests library.',
    keywords='requests aws',
    license='ISC',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'License :: OSI Approved :: ISC License (ISCL)',
    ],
)